@@ -7,7 +7,7 @@ use Carp    qw(carp cluck croak confess);
 use base 'Bio::ToolBox::Data::core';
 use Bio::ToolBox::Data::Feature;
 
-our $VERSION = '2.00';
+our $VERSION = '2.02';
 
 #### Initialize ####
 
@@ -78,6 +78,9 @@ sub new {
 			foreach my $c (@columns) {
 				$self->add_column($c);
 			}
+			if ( exists $args{noheader} and defined $args{noheader} ) {
+				$self->headers( $args{noheader} );
+			}
 		}
 		elsif ( exists $args{gff} and $args{gff} ) {
 
@@ -135,22 +138,26 @@ sub new {
 }
 
 sub duplicate {
-	my ( $self, $filename ) = @_;
-	unless ($filename) {
-		carp 'ERROR: a new filename must be provided!';
-		return;
-	}
-	if ( $filename eq $self->filename ) {
+	my $self     = shift;
+	my $filename = shift || undef;
+	if ( $filename and $filename eq $self->filename ) {
 		carp 'ERROR: provided filename is not unique from that in metadata!';
 		return;
 	}
 
 	# duplicate the data structure
 	my $columns = $self->list_columns;
-	my $Dup     = $self->new(
-		'out'     => $filename,
-		'columns' => $columns,
-	) or return;
+	my $Dup;
+	if ($filename) {
+		$Dup = $self->new(
+			'out'     => $filename,
+			'columns' => $columns,
+		) or return;
+	}
+	else {
+		$Dup = Bio::ToolBox::Data->new( 'columns' => $columns )
+			or return;
+	}
 
 	# copy the metadata
 	for my $i ( 1 .. $self->number_columns ) {
@@ -462,7 +469,7 @@ object is prepared, therefore column names must be provided.
 Boolean option indicating that the input file does not have file headers, 
 in which case dummy headers are provided. This is not necessary for 
 defined file types that don't normally have file headers, such as 
-BED, GFF, or UCSC files. Ignored for output files.
+BED, GFF, or UCSC files.
 
 =item columns
 
@@ -516,10 +523,15 @@ compatibility.
 =item duplicate
 
    my $Out_Stream = $Stream->duplicate($new_filename);
+   my $Data       = $Stream->duplicate;
+
+For an opened-to-read Stream object, you may duplicate the object as a new
+object. If a file name is provided, then a opened-to-write Stream object will be
+returned; the file name must be different from the existing read object. If no
+file name is provided, then an empty L<Bio::ToolBox::Data> object will be
+returned. The same number of columns, column names, and metadata will be
+assigned to the new object. 
 
-For an opened-to-read Stream object, you may duplicate the object as a new 
-opened-to_write Stream object that maintains the same columns and metadata. 
-A new different filename must be provided. 
 
 =back
 
